% 
% The SE PSR-1100-F Spectroradiometer measures 
% light at 1.5 nm sampling and 3.2 nm spectral 
% resolution over the 320 nm to 1100 nm spectral 
% range. However, due to the difficulty in calibrating 
% the 99% Spectralon plaque below 360 nm and the 
% low signal-to-noise ratio received from the water 
% above 850 nm, we generally only output spectra in 
% the 360-850 nm range.
% 
% Rrs is estimated from the above-water data using the formula,
% 	Rrs = (Sw+s - Ssky ?(?))/( ?Sp/refl),
% 
% where Sw+s is the measured signal from the water 
% and includes both Lw and reflected skylight.  
% Ssky is the measured signal from the sky, 
% Sp is the average measured signal from the 
% white Spectralon Plaque, and refl is the 
% reflectivity of the plaque (approximately 
% 99%; actual measured spectral values used 
% in the calculation). Pi (?) converts the reflected 
% radiance values to irradiance for this Lambertian 
% diffuser. The measured sky radiance is multiplied 
% by ?(?) which is the proportionality factor that 
% relates the radiance measured when the detector 
% views the sky to the reflected sky radiance 
% measured when the detector views the sea surface. 
%
% r1 - water
% r2 - sky
% r3 - reference
%

function [wl rrs rrsopt redmin] = computerrs(wl, ravg, mf, plotscale, mdata);

XMIN    = 350.00; XMAX = 850.00;
YMIN    =   0.00; YMAX =  0.02;
BMINidx =  42; % value at wavelength ~ 350 nm
RMINidx = 203; % ~ 600 nm
% RMINidx = 295; % ~ 750 nm
% RMAXidx = 325; % ~ 800 nm
RMAXidx = 355; % ~ 850 nm

dirin        = mdata.dirin;
directorystr = mdata.directorystr;
datestr      = mdata.datestr;
r1 = ravg(:,1); r2 = ravg(:,2); r3 = ravg(:,3);

rrs = (r1 - mf*r2)./((pi*r3)/(0.99));

figure('units','normalized','outerposition',[0 0 1 1]); hold on;
plot(wl, rrs, 'b', 'LineWidth', 5);
if (plotscale == 0)
     ymax = YMAX;
else 
     ymax = max(rrs(BMINidx:RMAXidx));
end
axis([XMIN XMAX YMIN ymax]);
xlabel('Wavelength (nm)'); ylabel('Remote Sensing Reflectance (R_{rs})');
tu = title([directorystr, '  ', datestr]);
set(tu,'Interpreter','none');
set(gca, 'FontSize', 20);
text(650, ymax*0.019/YMAX, 'R_{rs}', 'Color', 'b', 'FontSize', 30);
text(650, ymax*0.017/YMAX, ['R_{rs} - min[R_{rs}(',num2str(wl(RMINidx),3) ...
    ,'-',num2str(wl(RMAXidx),3),')]'], ...
    'Color', 'r', 'FontSize', 30);

redmin = min(rrs(RMINidx:RMAXidx));
rrsopt = rrs - redmin;
plot(wl, rrsopt, 'r', 'LineWidth', 5);
hold off;
screencapture(gcf,[],[dirin,'f_rrs.png']); 
end

